{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": ".dict file",
            "baseCommand": [
                "java",
                "-jar",
                "/opt/picard/CreateSequenceDictionary.jar"
            ],
            "arguments": [
                "OUTPUT=$(inputs.to_dict.nameroot).dict"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "opengenomics/picard-tool:1.122"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.to_dict)",
                            "writable": true
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "REFERENCE=",
                        "separate": false
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#dict.cwl/to_dict"
                }
            ],
            "id": "#dict.cwl",
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.to_dict.basename)"
                    },
                    "id": "#dict.cwl/dict"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": ".fai file",
            "baseCommand": [
                "samtools"
            ],
            "arguments": [
                "faidx"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "opengenomics/samtools:1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.to_index)",
                            "writable": true
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fai.cwl/to_index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.to_index.basename)"
                    },
                    "id": "#fai.cwl/faidx"
                }
            ],
            "id": "#fai.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "unzip file",
            "baseCommand": [
                "gzip"
            ],
            "stdout": "$(inputs.zipped.nameroot)",
            "arguments": [
                "-c",
                "-d"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gzip.cwl/zipped"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.zipped.nameroot)"
                    },
                    "id": "#gzip.cwl/unzipped"
                }
            ],
            "id": "#gzip.cwl"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/zipped"
                }
            ],
            "steps": [
                {
                    "run": "#dict.cwl",
                    "in": [
                        {
                            "source": "#main/index_ref/faidx",
                            "id": "#main/dict_ref/to_dict"
                        }
                    ],
                    "out": [
                        "#main/dict_ref/dict"
                    ],
                    "id": "#main/dict_ref"
                },
                {
                    "run": "#fai.cwl",
                    "in": [
                        {
                            "source": "#main/unzip_ref/unzipped",
                            "id": "#main/index_ref/to_index"
                        }
                    ],
                    "out": [
                        "#main/index_ref/faidx"
                    ],
                    "id": "#main/index_ref"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#main/zipped",
                            "id": "#main/unzip_ref/zipped"
                        }
                    ],
                    "out": [
                        "#main/unzip_ref/unzipped"
                    ],
                    "id": "#main/unzip_ref"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.fai",
                        ".dict"
                    ],
                    "outputSource": "#main/dict_ref/dict",
                    "id": "#main/prepped_ref"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
